@@ -8,7 +8,7 @@ use warnings;
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
 $DEBUG = 0;
-$VERSION = '0.38';
+$VERSION = '0.39';
 
 use base qw(Class::Accessor);
 XML::Sig->mk_accessors(qw(key));
@@ -234,8 +234,10 @@ sub verify {
         print ("   Digest Method: $digest_method\n") if $DEBUG;
 
         # Get the DigestValue used to verify Canonical XML
-        my $refdigest = _trim($self->{ parser }->findvalue(
-                'dsig:SignedInfo/dsig:Reference/dsig:DigestValue', $signature_node));
+        # Note that the digest may have embedded newlines in the XML
+        # Decode the base64 and encode it with no newlines
+        my $refdigest = encode_base64(decode_base64(_trim($self->{ parser }->findvalue(
+                'dsig:SignedInfo/dsig:Reference/dsig:DigestValue', $signature_node))), "");
         print ("   Digest Value: $refdigest\n") if $DEBUG;
 
         # Get the SignatureValue used to verify the SignedInfo
@@ -328,7 +330,7 @@ sub verify {
         # Obtain the DigestValue of the Canonical XML
         my $digest = $self->{digest_method}->($canonical);
 
-        print ( "    Reference Digest " . _trim($refdigest) ."\n") if $DEBUG;
+        print ( "    Reference Digest:  " . _trim($refdigest) ."\n") if $DEBUG;
 
         print ( "    Calculated Digest: ". _trim(encode_base64($digest, '')) ."\n") if $DEBUG;
 
@@ -1201,7 +1203,7 @@ XML::Sig
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
